@@ -107,6 +107,12 @@ def parse_args(args):
         action="store_true",
         default=False,
         help="generate Travis configuration files")
+    parser.add_argument(
+        "--with-gitlab-ci",
+        dest="gitlab_ci",
+        action="store_true",
+        default=False,
+        help="generate GitLab-CI configuration files")
     parser.add_argument(
         "--with-pre-commit",
         dest="pre_commit",
